<?php

/**
 * Find a user by username, email, or id.
 */
function user_find(string|int $user): array|false
{
	$result = db_query(db_auth(), "SELECT * FROM users WHERE username = :u OR email = :u OR id = :u", [':u' => $user]);
	$user = $result->fetchArray(SQLITE3_ASSOC);
	if (!$user) return false;
	$result->finalize();
	return $user;
}

/**
 * Create a user with a username, email, and password. Optionally pass an auth level. This function will not check
 * if the username or email already exists. It is up to the caller to check this before calling this function. It is
 * also up to the caller to validate password strength. This function will hash the password with the PASSWORD_ARGON2ID
 * algorithm.
 */
function user_create(string $username, string $email, string $password, int $auth = 0): SQLite3Result|false
{
	return db_query(db_auth(), "INSERT INTO users (username, email, password, auth) VALUES (:u, :e, :p, :a)", [
		':u' => $username,
		':e' => $email,
		':p' => password_hash($password, PASSWORD_ARGON2ID),
		':a' => $auth
	]);
}

/**
 * Delete a user by username, email, or id.
 */
function user_delete(string|int $user): SQLite3Result|false
{
	return db_query(db_auth(), "DELETE FROM users WHERE username = :u OR email = :u OR id = :u", [':u' => $user]);
}
